@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 use CPAN::Changes;
 
@@ -22,7 +22,7 @@ sub before_release {
 
     $self->zilla->ensure_built_in;
 
-    my $file = $self->zilla->built_in->file('Changes');
+    my $file = $self->zilla->built_in->child('Changes');
 
     if ( !-e $file ) {
         $self->log_fatal('No Changes file found');
@@ -70,7 +70,7 @@ Dist::Zilla::Plugin::DROLSKY::CheckChangesHasContent - Checks Changes for conten
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =for Pod::Coverage .*
 
