@@ -7,9 +7,9 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
-use Dist::Zilla;
+use Dist::Zilla 6.0;
 
 # For the benefit of AutoPrereqs
 use Dist::Zilla::Plugin::Authority;
@@ -718,7 +718,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 DESCRIPTION
 
